@@ -13,7 +13,12 @@ tmesh3d <- function( vertices, indices, homogeneous=TRUE, material=NULL, normals
     material$meshColor <- NULL
   }
   meshColor <- match.arg(meshColor)
-  
+  if (missing(texcoords)
+      && !is.null(material)
+      && !is.null(material$texcoords)) {
+    texcoords <- material$texcoords
+    material$texcoords <- NULL
+  }
   if (homogeneous == TRUE)
     vrows <- 4
   else
@@ -63,7 +68,12 @@ qmesh3d <- function( vertices, indices, homogeneous=TRUE, material=NULL, normals
     material$meshColor <- NULL
   }  
   meshColor <- match.arg(meshColor)
-  
+  if (missing(texcoords)
+      && !is.null(material)
+      && !is.null(material$texcoords)) {
+    texcoords <- material$texcoords
+    material$texcoords <- NULL
+  }  
   if (homogeneous == TRUE)
     vrows <- 4
   else
@@ -173,171 +183,25 @@ as.mesh3d.tri <- function(x, z, col = "gray",
 
 # rendering support
 
-dot3d.mesh3d <- function ( x, override = TRUE, 
-                            meshColor = c("vertices", "edges", "faces", "legacy"), ... ) {
-  argMaterial <- .getMaterialArgs(...)
-  hasMeshColor <- !missing(meshColor)
-  if ( override ) {
-    material <- x$material
-    if (is.null(material)) material <- list()    
-    material[names(argMaterial)] <- argMaterial
-    if (hasMeshColor || is.null(x$meshColor))
-      meshColor <- match.arg(meshColor)
-    else
-      meshColor <- x$meshColor
-  } else {
-    material <- argMaterial
-    material[names(x$material)] <- x$material
-    if (is.null(x$meshColor))
-      meshColor <- match.arg(meshColor)
-    else
-      meshColor <- x$meshColor
-  }
-  if (meshColor != "legacy") {
-    if (is.null(material$color))
-      material$color <- material3d("color")
-    if (is.null(material$alpha))
-      material$alpha <- material3d("alpha")
-  }
-  
-  result <- integer(0)
-  if (!is.null(x$it)) {
-    args <- c(list(x = x$vb[1,x$it]/x$vb[4,x$it],
-                   y = x$vb[2,x$it]/x$vb[4,x$it],
-                   z = x$vb[3,x$it]/x$vb[4,x$it]), 
-              material)
-    if (meshColor != "legacy") {
-      if (length(unique(args$color)) > 1) {
-        if (!hasMeshColor && getOption("rgl.meshColorWarning", FALSE))
-          warning("Default coloring for meshes changed in rgl 0.100.1")
-        args$color <- switch(meshColor,
-                             vertices = rep_len(args$color, ncol(x$vb))[x$it],
-                             edges    = rep(args$color, each = 2),
-                             faces    = rep(args$color, each = 3))
-      }
-      if (length(unique(args$alpha)) > 1)
-        args$alpha <- switch(meshColor,
-                             vertices = rep_len(args$alpha, ncol(x$vb))[x$it],
-                             edges    = rep(args$alpha, each = 2),
-                             faces    = rep(args$alpha, each = 3))
-    }
-    result <- c(triangles = do.call(points3d, args))
-  }
-  if (!is.null(x$ib)) {
-    args <- c(list(x = x$vb[1,x$ib]/x$vb[4,x$ib],
-                   y = x$vb[2,x$ib]/x$vb[4,x$ib],
-                   z = x$vb[3,x$ib]/x$vb[4,x$ib]), 
-              material)
-    
-    if (meshColor != "legacy") {
-      if (length(unique(args$color)) > 1) 
-        args$color <- switch(meshColor,
-                             vertices = rep_len(args$color, ncol(x$vb))[x$ib],
-                             edges = rep(args$color, each = 2),
-                             faces = rep(args$color, each = 4))
-      if (length(unique(args$alpha)) > 1) 
-        args$alpha <- switch(meshColor,
-                             vertices = rep_len(args$alpha, ncol(x$vb))[x$ib],
-                             edges = rep(args$alpha, each = 2),
-                             faces = rep(args$alpha, each = 4))
-    }
-    result <- c(result, quads = do.call(points3d, args))
-  }
-  lowlevel(result)
-}
+dot3d.mesh3d <- function(x, ..., front = "points", back = "points")
+  shade3d.mesh3d(x, ..., front = front, back = back)
 
 dot3d.qmesh3d <- dot3d.mesh3d   # for back-compatibility
 
-wire3d.mesh3d <- function ( x, override = TRUE, 
-                            meshColor = c("vertices", "edges", "faces", "legacy"), ... ) {
-  argMaterial <- .getMaterialArgs(...)
-  hasMeshColor <- !missing(meshColor)
-  if ( override ) {
-    material <- x$material
-    if (is.null(material)) material <- list()    
-    material[names(argMaterial)] <- argMaterial
-    if (hasMeshColor || is.null(x$meshColor))
-      meshColor <- match.arg(meshColor)
-    else
-      meshColor <- x$meshColor
-  } else {
-    material <- argMaterial
-    material[names(x$material)] <- x$material
-    if (is.null(x$meshColor))
-      meshColor <- match.arg(meshColor)
-    else
-      meshColor <- x$meshColor
-  }
-  if (meshColor != "legacy") {
-    if (is.null(material$color))
-      material$color <- material3d("color")
-    if (is.null(material$alpha))
-      material$alpha <- material3d("alpha")
-  }
-  if (meshColor != "edges") {
-    material["front"] <- "lines"
-    material["back"] <- "lines"
-  } 
-  
-  result <- integer(0)
-  if (!is.null(x$it)) {
-    fn <- triangles3d
-    if (meshColor == "edges") {
-      x$it <- x$it[c(1,2,2,3,3,1),]
-      fn <- segments3d
-    }
-    args <- c(list(x = x$vb[1,x$it]/x$vb[4,x$it],
-                   y = x$vb[2,x$it]/x$vb[4,x$it],
-                   z = x$vb[3,x$it]/x$vb[4,x$it]), 
-             material)
-    if (meshColor != "legacy") {
-      if (length(unique(args$color)) > 1) {
-        if (!hasMeshColor && getOption("rgl.meshColorWarning", FALSE))
-          warning("Default coloring for meshes changed in rgl 0.100.1")
-        args$color <- switch(meshColor,
-          vertices = rep_len(args$color, ncol(x$vb))[x$it],
-          edges    = rep(args$color, each = 2),
-          faces    = rep(args$color, each = 3))
-      }
-      if (length(unique(args$alpha)) > 1)
-        args$alpha <- switch(meshColor,
-          vertices = rep_len(args$alpha, ncol(x$vb))[x$it],
-          edges    = rep(args$alpha, each = 2),
-          faces    = rep(args$alpha, each = 3))
-    }
-    result <- c(triangles = do.call(fn, args))
-  }
-  if (!is.null(x$ib)) {
-    fn <- quads3d
-    if (meshColor == "edges") {
-      x$ib <- x$ib[c(1,2,2,3,3,4,4,1),]
-      fn <- segments3d
-    }
-    args <- c(list(x = x$vb[1,x$ib]/x$vb[4,x$ib],
-                   y = x$vb[2,x$ib]/x$vb[4,x$ib],
-                   z = x$vb[3,x$ib]/x$vb[4,x$ib]), 
-            material)
-    
-    if (meshColor != "legacy") {
-      if (length(unique(args$color)) > 1) 
-        args$color <- switch(meshColor,
-          vertices = rep_len(args$color, ncol(x$vb))[x$ib],
-          edges = rep(args$color, each = 2),
-          faces = rep(args$color, each = 4))
-      if (length(unique(args$alpha)) > 1) 
-        args$alpha <- switch(meshColor,
-          vertices = rep_len(args$alpha, ncol(x$vb))[x$ib],
-          edges = rep(args$alpha, each = 2),
-          faces = rep(args$alpha, each = 4))
-    }
-    result <- c(result, quads = do.call(fn, args))
-  }
-  lowlevel(result)
+wire3d.mesh3d <- function(x, ..., front = "lines", back = "lines")
+  shade3d.mesh3d(x, ..., front = front, back = back)
+
+allowedMeshColor <- function(meshColor, modes) {
+  meshColor != "edges" || 
+    (modes[1] == modes[2] && modes[1] == "lines")
 }
 
 shade3d.mesh3d <- function ( x, override = TRUE, 
-                             meshColor = c("vertices", "faces", "legacy"), ... ) {
-  argMaterial <- .getMaterialArgs(...)
+                             meshColor = c("vertices", "edges", "faces", "legacy"), 
+                             texcoords = NULL, 
+                             ...,
+                             front = "filled", back = "filled") {
+  argMaterial <- c(list(front = front, back = back), .getMaterialArgs(...))
   xHasColor <- !is.null(x$material) && !is.null(x$material$color)
   hasMeshColor <- !missing(meshColor)
   if ( override ) {
@@ -348,6 +212,8 @@ shade3d.mesh3d <- function ( x, override = TRUE,
       meshColor <- match.arg(meshColor)
     else
       meshColor <- x$meshColor
+    if (is.null(texcoords) && !is.null(x$texcoords))
+      texcoords <- t(x$texcoords)
   } else {
     material <- argMaterial
     material[names(x$material)] <- x$material
@@ -355,9 +221,13 @@ shade3d.mesh3d <- function ( x, override = TRUE,
       meshColor <- match.arg(meshColor)
     else
       meshColor <- x$meshColor
+    if (!is.null(x$texcoords))
+      texcoords <- t(x$texcoords)
   }
-  if (!(meshColor %in% (allowedMeshColor <- eval(formals()$meshColor))))
-    stop("'meshColor' must be one of: ", paste(allowedMeshColor, collapse = ", "))
+  modes <- c(front, back)
+  if (!allowedMeshColor(meshColor, modes))
+    stop("'meshColor = ", meshColor, "' not supported.")
+  
   if (meshColor != "legacy") {
     if (is.null(material$color))
       material$color <- material3d("color")
@@ -367,6 +237,8 @@ shade3d.mesh3d <- function ( x, override = TRUE,
   result <- integer(0)
   ntriangles <- 0
   if (!is.null(x$it)) {
+    if (meshColor == "edges")
+      x$it <- x$it[c(1,2,2,3,3,1),]
     ntriangles <- ncol(x$it)
     args <- c(list(x = x$vb[1,x$it]/x$vb[4,x$it],
                    y = x$vb[2,x$it]/x$vb[4,x$it],
@@ -374,10 +246,7 @@ shade3d.mesh3d <- function ( x, override = TRUE,
                    material)
     if (!is.null(x$normals) && is.null(args$normals)) 
       args <- c(args, list(normals = t(x$normals[,x$it])))
-    if (!is.null(x$texcoords) && is.null(args$texcoords))
-      args <- c(args, list(texcoords = t(x$texcoords[,x$it])))
     if (meshColor != "legacy") {
-      
       if (length(unique(args$color)) > 1) {
         if (!xHasColor && !hasMeshColor && getOption("rgl.meshColorWarning", FALSE))
           warning("Default coloring for meshes changed in rgl 0.100.1")
@@ -391,10 +260,24 @@ shade3d.mesh3d <- function ( x, override = TRUE,
           vertices = rep_len(args$alpha, ncol(x$vb))[x$it],
           faces = rep(args$alpha, each = 3)
         )
+      if (!is.null(texcoords)) {
+        indices <- seq_len(nrow(texcoords))
+        indices <- switch(meshColor,
+          vertices = rep_len(indices, ncol(x$vb))[x$it],
+          faces = rep(indices, each = 3)
+        )
+        args$texcoords <- texcoords[indices,]
+      }
     }
-    result <- c(triangles = do.call("triangles3d", args = args ))
+    if (meshColor == "edges") 
+      fn <- segments3d
+    else
+      fn <- triangles3d
+    result <- c(triangles = do.call(fn, args = args ))
   }
   if (!is.null(x$ib)) {
+    if (meshColor == "edges")
+      x$ib <- x$ib[c(1,2,2,3,3,4,4,1),]
     args <- c(list(x = x$vb[1,x$ib]/x$vb[4,x$ib],
                    y = x$vb[2,x$ib]/x$vb[4,x$ib],
                    z = x$vb[3,x$ib]/x$vb[4,x$ib]), 
@@ -419,8 +302,23 @@ shade3d.mesh3d <- function ( x, override = TRUE,
             rep(temp[ntriangles + seq_len(nquads)], each = 4)
           })
       }
+      if (!is.null(texcoords)) {
+        nquads <- ncol(x$ib)
+        indices <- seq_len(nrow(texcoords))
+        indices <- switch(meshColor,
+                        vertices = rep_len(indices, ncol(x$vb))[x$ib],
+                        faces = {
+                          temp <- rep_len(indices, ntriangles + nquads)
+                          rep(temp[ntriangles + seq_len(nquads)], each = 4)
+                        })
+        args$texcoords <- texcoords[indices,]
+      }
     }
-    result <- c(result, quads = do.call("quads3d", args = args ))
+    if (meshColor == "edges")
+      fn <- segments3d
+    else
+      fn <- quads3d
+    result <- c(result, quads = do.call(fn, args = args ))
   }
   lowlevel(result)
 }
@@ -452,7 +350,8 @@ scale3d.mesh3d <- function ( obj, x, y, z, ... ) {
   if ( !is.null(obj$normals) ) {
     obj$normals <- scale3d(t(obj$normals), 1/x, 1/y, 1/z)
     obj$normals <- t( obj$normals/sqrt(apply(obj$normals[,1:3]^2, 1, sum)) )
-    obj$normals[4,] <- 1
+    if (nrow(obj$normals) == 4)
+      obj$normals[4,] <- 1
   }
   return(obj)
 }
