@@ -5,7 +5,7 @@ rglMouse <- function(sceneId,
 				 "none"),
 	             labels = choices,
 	             button = 1, 
-		     dev = rgl.cur(), 
+		     dev = cur3d(), 
 		     subscene = currentSubscene3d(dev),
 	             default = par3d("mouseMode", dev = dev, subscene = subscene)[button],
 		     stayActive = FALSE,
@@ -45,4 +45,4 @@ rglMouse <- function(sceneId,
                                    ncol = 1)))
   else
     browsable(result)
-}
\ No newline at end of file
+}
