@@ -1,4 +1,4 @@
-currentSubscene3d <- function(dev = rgl.cur()) {
+currentSubscene3d <- function(dev = cur3d()) {
   .C(rgl_getsubsceneid, id = 1L, dev = as.integer(dev))$id
 }
 
@@ -6,7 +6,7 @@ subsceneInfo <- function(id = NA, embeddings, recursive = FALSE) {
   if (is.na(id)) 
     id <- currentSubscene3d()
   else if (is.character(id) && id == "root") 
-    id <- .C(rgl_getsubsceneid, id = 0L, dev = as.integer(rgl.cur()))$id
+    id <- .C(rgl_getsubsceneid, id = 0L, dev = as.integer(cur3d()))$id
   if (!id) stop("No subscene info available.")
   id <- as.integer(id)
   result <- list(id = id)
@@ -78,7 +78,7 @@ newSubscene3d <- function(viewport = "replace",
   if (id) {
     if (copyLights || copyShapes || copyBBoxDeco || copyBackground) {
       useSubscene3d(parent)
-      ids <- rgl.ids(type = 
+      ids <- ids3d(type = 
         c("lights", "shapes", "bboxdeco", "background")[c(copyLights, copyShapes, copyBBoxDeco, copyBackground)])$id
       if (length(ids)) 
         addToSubscene3d(ids, subscene = id)
@@ -102,7 +102,7 @@ useSubscene3d <- function(subscene) {
 
 addToSubscene3d <- function(ids, subscene = currentSubscene3d()) {
   ids <- as.integer(ids)
-  dups <- intersect(ids, rgl.ids("all", subscene)$id)
+  dups <- intersect(ids, ids3d("all", subscene)$id)
   if (length(dups))
     stop(gettextf("Cannot add %s, already present", paste(dups, collapse = ", ")), domain = NA)
   result <- .C(rgl_addtosubscene, success = as.integer(subscene), 
@@ -128,7 +128,7 @@ gc3d <- function(protect=NULL) {
   invisible( .C(rgl_gc, n = length(protect), protect)$n )
 }
 
-subsceneList <- function(value, window = rgl.cur()) {
+subsceneList <- function(value, window = cur3d()) {
   alllists <- .rglEnv$subsceneLists  
   # This cleans up lists for closed windows:
   alllists <- alllists[names(alllists) %in% rgl.dev.list()]
@@ -152,7 +152,7 @@ next3d <- function(current = NA, clear = TRUE, reuse = TRUE) {
     subscenes <- current
   
   this <- which(current == subscenes)
-  if (reuse && !nrow(rgl.ids(subscene = current))) {
+  if (reuse && !nrow(ids3d(subscene = current))) {
     # do nothing
   } else if (this == length(subscenes)) 
     this <- 1
@@ -175,9 +175,9 @@ next3d <- function(current = NA, clear = TRUE, reuse = TRUE) {
 }
   
 clearSubsceneList <- function(delete = currentSubscene3d() %in% subsceneList(),
-                              window = rgl.cur()) {
+                              window = cur3d()) {
   if (!missing(window))
-    rgl.set(window)  
+    set3d(window)  
   thelist <- subsceneList()
   if (delete && length(thelist)) {
     parent <- subsceneInfo(thelist[1])$parent
