@@ -11,12 +11,13 @@ using namespace rgl;
 //
 
 SphereSet::SphereSet(Material& in_material, int in_ncenter, double* in_center, int in_nradius, double* in_radius,
-                     int in_ignoreExtent)
+                     int in_ignoreExtent, bool in_fastTransparency)
  : Shape(in_material, in_ignoreExtent, SHAPE, true), 
    center(in_ncenter, in_center), 
    radius(in_nradius, in_radius),
    lastdrawn(-1),
-   lastendcap(true)
+   lastendcap(true),
+   fastTransparency(in_fastTransparency)
 {
   material.colorPerVertex(false);
 
@@ -61,6 +62,17 @@ void SphereSet::drawBegin(RenderContext* renderContext)
 
 void SphereSet::drawPrimitive(RenderContext* renderContext, int index) 
 {
+  if (fastTransparency) {
+    
+    if ( center.get(index).missing() || ISNAN(radius.getRecycled(index)) ) return;
+    
+    material.useColor(index);
+    sphereMesh.setCenter( center.get(index) );
+    sphereMesh.setRadius( radius.getRecycled(index) );
+    sphereMesh.update( renderContext->subscene->getModelViewpoint()->scale );
+    sphereMesh.draw(renderContext);
+    
+  } else {
    int i1 = index / facets, i2 = index % facets;
    bool endcap = i2 < sphereMesh.getSegments() 
    	      || i2 >= facets - sphereMesh.getSegments();
@@ -85,6 +97,7 @@ void SphereSet::drawPrimitive(RenderContext* renderContext, int index)
      lastendcap = endcap;
    }
    sphereMesh.drawPrimitive(renderContext, i2);
+  }
 }
 
 void SphereSet::drawEnd(RenderContext* renderContext)
@@ -105,21 +118,25 @@ void SphereSet::render(RenderContext* renderContext)
 
 int SphereSet::getPrimitiveCount()
 {
-  return facets * getElementCount();
+  return (fastTransparency ? 1 : facets) * getElementCount();
 }
 
 Vertex SphereSet::getPrimitiveCenter(int index)
 {
-  int i1 = index / facets, i2 = index % facets;
-  if (i1 != lastdrawn) {
-    if ( center.get(i1).missing() || ISNAN(radius.getRecycled(i1)) ) return center.get(i1);
-    sphereMesh.setCenter( center.get(i1) );
-    sphereMesh.setRadius( radius.getRecycled(i1) );
-    sphereMesh.update();
-    
-    lastdrawn = i1;
+  if (fastTransparency) {
+    return center.get(index);
+  } else {
+    int i1 = index / facets, i2 = index % facets;
+    if (i1 != lastdrawn) {
+      if ( center.get(i1).missing() || ISNAN(radius.getRecycled(i1)) ) return center.get(i1);
+      sphereMesh.setCenter( center.get(i1) );
+      sphereMesh.setRadius( radius.getRecycled(i1) );
+      sphereMesh.update();
+      
+      lastdrawn = i1;
+    }
+    return sphereMesh.getPrimitiveCenter(i2);
   }
-  return sphereMesh.getPrimitiveCenter(i2);
 }
 		
 	
@@ -128,6 +145,7 @@ int SphereSet::getAttributeCount(AABox& bbox, AttribID attrib)
   switch (attrib) {
     case RADII:    return radius.size();
     case VERTICES: return center.size();
+    case FLAGS:    return 2;    
   }
   return Shape::getAttributeCount(bbox, attrib);
 }
@@ -150,6 +168,10 @@ void SphereSet::getAttribute(AABox& bbox, AttribID attrib, int first, int count,
         while (first < n) 
           *result++ = radius.get(first++);
         return;
+      case FLAGS:
+        if (first == 0) *result++ = ignoreExtent;
+        *result++ = (double) fastTransparency;
+        return;
     }  
     Shape::getAttribute(bbox, attrib, first, count, result);
   }
