@@ -76,6 +76,8 @@ Texture::~Texture()
   }
   if (pixmap)
     delete pixmap;
+  if (filename)
+    delete[] filename;
 }
 
 
