@@ -76,7 +76,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
   /* Some systems write useless messages to stderr.  We'll
    * hide those
    */
-  int stderr_copy;
+  int stderr_copy = STDERR_FILENO; /* suppress "maybe undefined" warning */
   if (!rglDebug) {
      int devNull = 
 #ifdef windows
@@ -159,7 +159,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    {"rgl_attrib_count", 	(DL_FUNC) &rgl_attrib_count, 3, aIII}, 
    {"rgl_attrib", 		(DL_FUNC) &rgl_attrib, 5, aIIIID}, 
    {"rgl_text_attrib", 		(DL_FUNC) &rgl_text_attrib, 5, aIIIIS}, 
-   {"rgl_bg", 			(DL_FUNC) &rgl_bg, 2, aLI},
+   {"rgl_bg", 			(DL_FUNC) &rgl_bg, 3, aLID},
    {"rgl_bbox", 		(DL_FUNC) &rgl_bbox, 9, aLIDDSDSDS}, 
    {"rgl_light",		(DL_FUNC) &rgl_light, 3, aIID},
    {"rgl_pixels",		(DL_FUNC) &rgl_pixels, 5, aLIIIF},
@@ -168,7 +168,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    {"rgl_abclines",		(DL_FUNC) &rgl_abclines, 4, aIIDD},
    {"rgl_primitive",		(DL_FUNC) &rgl_primitive, 5, aIIDDD},
    {"rgl_surface", 		(DL_FUNC) &rgl_surface, 13, aIIDDDDDDDDIII},
-   {"rgl_spheres",		(DL_FUNC) &rgl_spheres, 4, aIIDD},
+   {"rgl_spheres",		(DL_FUNC) &rgl_spheres, 5, aIIDDI},
    {"rgl_texts",		(DL_FUNC) &rgl_texts, 12, aIIDSDISIDIII},
    {"rgl_sprites",  		(DL_FUNC) &rgl_sprites, 6, aIIDDID},
    {"rgl_newsubscene",		(DL_FUNC) &rgl_newsubscene, 4, aIIII},
@@ -213,7 +213,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    FUNDEF(rgl_attrib_count, 3), 
    FUNDEF(rgl_attrib, 5), 
    FUNDEF(rgl_text_attrib, 5), 
-   FUNDEF(rgl_bg, 2),
+   FUNDEF(rgl_bg, 3),
    FUNDEF(rgl_bbox, 9), 
    FUNDEF(rgl_light, 3),
    FUNDEF(rgl_pixels, 5),
@@ -222,7 +222,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    FUNDEF(rgl_abclines, 4),
    FUNDEF(rgl_primitive, 5),
    FUNDEF(rgl_surface, 13),
-   FUNDEF(rgl_spheres, 4),
+   FUNDEF(rgl_spheres, 5),
    FUNDEF(rgl_texts, 12),
    FUNDEF(rgl_sprites, 6),
    FUNDEF(rgl_newsubscene, 4),
